/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.entities.player;
import game.Start;
import game.UserInput;
import game.entities.GameObject;
import game.entities.player.abilities.Ability;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

public class Player extends GameObject {

	public Random r;
	public UserInput ui;
	
	public int hunger;
	public int maxHunger;
	public int thirst;
	public int maxThirst;
	public int agility;
	
	public int attackSkill;
	public int searchSkill;
	public int chaseSkill;
	public int stealthSkill;
	public int intimidateSkill;
	
	public int level;
	public int xp;
	public int nextLevelXP;
	private int nextAttackLevel = 10;
	public int nextAttackProgress = 0;
	private int nextSearchLevel = 10;
	public int nextSearchProgress = 0;
	private int nextChaseLevel = 10;
	public int nextChaseProgress = 0;
	private int nextStealthLevel = 10;
	public int nextStealthProgress = 0;
	private int nextIntimidateLevel = 10;
	public int nextIntimidateProgress = 0;
	
	public int unusedUnlocks = 0;
	public int roarCooldown = 0;
	
	public static List<Ability> abilities = new ArrayList<Ability>();
	
	// actual default cooldown time
	public int rct;
	
	public Player(){
	
		health = 100;
		maxHealth = 100;
		hunger = 100;
		maxHunger = 100;
		thirst = 100;
		maxThirst = 100;
		level = 1;
		xp = 0;
		nextLevelXP = 1000;
		
		attackSkill = 1;
		searchSkill = 1;
		chaseSkill = 1;
		stealthSkill = 1;
		intimidateSkill = 1;
		speed = 20;
		stamina = 20;
		agility = 5;
		energy = stamina;
		rct = 5;
		
		abilities.add(Ability.bite);
		abilities.add(Ability.claw);
		abilities.add(Ability.pounce);
		abilities.add(Ability.grab);
		
		r = new Random();
		ui = new UserInput();
		this.create();
	}
	
	public void update(){
		
		hunger--;
		thirst--;
		
		if (health > maxHealth) health = maxHealth;
		if (hunger > maxHunger) hunger = maxHunger;
		if (thirst > maxThirst) thirst = maxThirst;
		
		if (hunger <= 0){
			hunger = 0;
			health -= 10;
		}
		
		if (thirst <= 0){
			thirst = 0;
			health -= 10;
		}
		
		roarCooldown--;
		if (roarCooldown < 0) roarCooldown = 0;
		
		if (health <= 0) isDead = true;
		
		if (energy > stamina) energy = stamina;
		
		if (xp >= nextLevelXP){
			levelUp();
		}
		
		if (nextAttackProgress >= nextAttackLevel){
			attackSkill++;
			nextAttackProgress = 0;
			System.out.println("Your attack skill has leveled up to " + attackSkill);
		}
		
		if (nextSearchProgress >= nextSearchLevel){
			searchSkill++;
			nextSearchProgress = 0;
			System.out.println("Your search skill has leveled up to " + searchSkill);
		}
		
		if (nextStealthProgress >= nextStealthLevel){
			stealthSkill++;
			nextStealthProgress = 0;
			System.out.println("Your stealth skill has leveled up to " + stealthSkill);
		}
		
		if (nextChaseProgress >= nextChaseLevel){
			chaseSkill++;
			nextChaseProgress = 0;
			System.out.println("Your chase skill has leveled up to " + chaseSkill);
		}
		
		if (nextIntimidateProgress >= nextIntimidateLevel){
			intimidateSkill++;
			nextIntimidateProgress = 0;
			System.out.println("Your intimidation skill has leveled up to " + intimidateSkill);
		}
		
	}
	
	public void pause(){
	}
	
	public int attack(){
		nextAttackProgress++;
		int a = r.nextInt(5) + attackSkill;
		energy--;
		return a;
	}
	
	public void eat(int foodValue){
		hunger += foodValue;
		health += foodValue;
	}
	
	public int roar(){
		if (roarCooldown <= 0){
			nextIntimidateProgress++;
			int b = r.nextInt(5) + intimidateSkill;
			roarCooldown = rct;
			return b;
		}else{
			System.out.println("You must wait " + Start.player.roarCooldown + " more turns before using roar again.");
			return -50;
		}
	}
	
	public int stalk(){
		int roll = r.nextInt(12 * stealthSkill);
		nextStealthProgress++;
		return roll;
	}
	
	public int search(){
		nextSearchProgress++;
		int roll = r.nextInt(10);
		int result = roll + searchSkill;
		return result;
	}
	
	public void drink(){
		thirst = maxThirst + 5;
	}

	public void stats() {
		System.out.println("Here are your stats:");
		System.out.println("Health = " + health);
		System.out.println("Hunger = " + hunger);
		System.out.println("Thirst = " + thirst);
		System.out.println("Energy = " + energy);
		System.out.println("XP = " + xp);
		System.out.println("Level = " + level);
		System.out.println("Attributes:");
		System.out.println("Speed = " + speed);
		System.out.println("Stamina (maximum energy) = " + stamina);
		System.out.println("Maximum health = " + maxHealth);
		System.out.println("Skills:");
		System.out.println("Attack skill = " + attackSkill + ", " + (nextAttackLevel - nextAttackProgress) + " points until next level");
		System.out.println("Search skill = " + searchSkill + ", " + (nextSearchLevel - nextSearchProgress) + " points until next level");
		System.out.println("Chase skill = " + chaseSkill + ", " + (nextChaseLevel - nextChaseProgress) + " points until next level");
		System.out.println("Stealth skill = " + stealthSkill + ", " + (nextStealthLevel - nextStealthProgress) + " points until next level");
	}

	public void chase() {
		energy--;
		nextChaseProgress++;
	}
	
	public void levelUp(){
		nextLevelXP = nextLevelXP + nextLevelXP + 300 * level;
		level++;
		System.out.println("You have levelled up to Level " + level);
		System.out.println("What do you want to unlock?");
		ui.selectAbility();
		ui.selectAttributes();
	}

}
