/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.entities.player.abilities;

import game.entities.player.Player;

public abstract class Ability {

	public boolean unlocked = false;
	public String name;
	public String unlockMsg;
	public int abilityID;
	
	public static Ability bite = new Bite();
	public static Ability claw = new Claw();
	public static Ability grab = new Grab();
	public static Ability pounce = new Pounce();
	
	public boolean checkPrereq(boolean silent){
		System.out.println("NOTICE: No prerequisite method could be found. Proceeding anyway.");
		return true;
	}
	
	
	public void unlock(){
		unlocked = true;
		System.out.println(unlockMsg);
	}
	
	public boolean tryAbility(){
		if (unlocked){
			use();
			return true;
		}else{
			System.out.println("You have not unlocked this ability.");
			return false;
		}
	}
	
	public void use(){
		System.out.println("ERROR: No use method could be found for this ability.");
	}
	
	public static Ability getAbility(String name){
		for (Ability ability : Player.abilities){
			if (ability.name == name) return ability;
		}
		return null;
	}
	
	public static Ability getAbility(int id){
		for (Ability ability: Player.abilities){
			if (ability.abilityID == id) return ability;
		}
		return null;
	}
	
}
