/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.events;
import game.Spawn;
import game.Start;
import game.entities.GameObject;
import game.entities.animals.enemies.Enemy;
import game.world.Environment;
import game.world.Weather;

import java.util.Random;


public class EmptyEvent extends Event {
	
	Random r;
	
	public EmptyEvent(String sm){
		
		startMessage = sm;
		
		event = this;
		isInput = true;
		firstEvent = true;
		r = new Random();
		
		create();
	}

	public void search(){
		
		int a = userinput.getSearchInput();
		int cost = r.nextInt(50) * 2 / Start.player.search();
		
		if (a == 1){
			invalidCommand = true;
		}else if(a == 2){
			System.out.println("It takes you " + cost + " hunger and thirst to find food.");
			Start.player.hunger -= cost;
			Start.player.thirst -= cost;
			Environment.time += cost;
			
			GameObject animal = Spawn.spawnRandomPassive();
			int c = r.nextInt(90) + 10;
			newEvent = new HuntEvent("You see a " + animal.name.toLowerCase() + " " + c + " metres away.", animal, c);
			newEvent.start();
		}else if(a == 3){
			System.out.println("It takes you " + cost + " hunger and thirst to find water.");
			Start.player.hunger -= cost;
			Start.player.thirst -= cost;
			Environment.time += cost;
			
			newEvent = new WateringHoleEvent("You have found a watering hole, a hotspot for local wildlife.");
			newEvent.start();
		}else if(a == 4){
			System.out.println("It takes you " + cost + " hunger and thirst to find shelter.");
			Start.player.hunger -= cost;
			Start.player.thirst -= cost;
			Environment.time += cost * 4;
			
			newEvent = new ShelterEvent("You find shelter under an acacia tree.");
			newEvent.start();
		}else if(a == 5){
			System.out.println("It takes you " + cost + " hunger and thirst to find an enemy to fight.");
			Start.player.hunger -= cost;
			Start.player.thirst -= cost;
			Environment.time += cost * 4;
			
			Enemy enemy = Spawn.spawnEnemy();
			int c = r.nextInt(30) + 10;
			newEvent = new FightEvent("You see a " + enemy.name.toLowerCase() + " " + c + " metres away.", enemy, c);
			newEvent.start();
		}else if(a == 6){
			if (Start.player.level >= 10){
				Enemy boss = Spawn.spawnBossHyena();
				newEvent = new BossEvent("You have found the alpha male of the hyenas! Let the battle begin...", boss, 20);
				newEvent.start();
			}else{
				System.out.println("Your attempts to find the hyena boss are in vain. Try again when you reach level 10.");
			}
		}

	}
	
	public void roam(){
		System.out.println("You roam for one hour.");
		Environment.time += 60;
		Start.player.hunger -= 14;
		Start.player.thirst -= 14;
		
		int roll = r.nextInt(100);
		System.out.println("Roll: " + roll);
		if (roll >= 0 && roll < 20){
			GameObject animal = Spawn.spawnRandomPassive();
			int c = r.nextInt(90) + 10;
			newEvent = new HuntEvent("You see a " + animal.name + " " + c + " metres away.", animal, c);
			newEvent.start();
		}else if (roll >= 20 && roll < 40){
			newEvent = new WateringHoleEvent("You have found a watering hole, a hotspot for local wildlife.");
			newEvent.start();
		}else if(roll >= 40 && roll < 60){
			newEvent = new ShelterEvent("You come across a tree that could be used as shelter.");
			newEvent.start();
		}else if (roll >= 26 && roll < 80){
			Enemy animal = Spawn.spawnEnemy();
			int c = r.nextInt(30) + 10;
			if (animal != null){
				newEvent = new FightEvent("You encounter a " + animal.name + " " + c + " metres away.", animal, c);
				newEvent.start();
			}else{
				System.out.println("You do not find anything whilst roaming on the plains.");
			}
		}else if (roll == 99){
			int r1 = r.nextInt();
			String eggName = "animal";
			if(r1 == 0) eggName = "penguin";
			else if(r1 == 1) eggName = "badger";
			else if(r1 == 2) eggName = "chicken";
			else if(r1 == 3) eggName = "fish";
			else if(r1 == 4) eggName = "bug";
			System.out.println("You meet a magical " + eggName + " who restores you to full strength!!");
			Start.player.health = Start.player.maxHealth;
			Start.player.hunger = Start.player.maxHunger;
			Start.player.thirst = Start.player.maxThirst;
		}else{
			System.out.println("You do not find anything whilst roaming on the plains.");
		}
		
	}
	
	public void sleep(){
		if (Weather.weatherID == 1){
			System.out.println("You try to sleep, but you can't sleep for long on the open plains. You are only slightly less fatigued.");
			Start.player.energy++;
		}else{
			System.out.println("You cannot sleep at all because of the weather.");
		}
	}
	
	public void endUpdate() {
		if (Start.player.isDead){
			System.out.println("You are dead. GAME OVER!");
		}
	}

}
