/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.events;

import game.Misc;
import game.Start;
import game.UserInput;
import game.entities.GameObject;

public abstract class Event {

	public String startMessage;
	public boolean isInput;
	public UserInput userinput;
	public int choice;
	public boolean repeat;
	public boolean invalidCommand;
	public Event event;
	public Event newEvent;
	public boolean firstEvent = false;
	
	
	public void create(){
		if (isInput){
			userinput = new UserInput();
		}
	}
	
	public void start(){
		System.out.println(startMessage);
		repeat = true;
		if(!firstEvent){
			for(GameObject go : Start.objects)
				go.update();
		}
		update();
	}
	
	abstract void endUpdate();
	
	public void update(){
	
		if (Start.player.hunger > Start.player.maxHunger){
			for(GameObject go : Start.objects)
				go.update();
		}
		if (Start.player.thirst > Start.player.maxThirst){
			for(GameObject go : Start.objects)
				go.update();
		}
		if (!invalidCommand){
			System.out.println();
			System.out.println("Health = " + Start.player.health + ". Hunger = " + Start.player.hunger + ". Thirst = " + Start.player.thirst + ". Energy = " + Start.player.energy + ". What is your next action?");
		}
		
		
		invalidCommand = false;
		if (isInput){
			choice = userinput.getInput();
		}
		
		choices();
		
		if (repeat && !invalidCommand){
			for(GameObject go : Start.objects)
				go.update();
		
		
			Start.environ.update();
		
			if (Start.player.hunger <= 0 && !Start.gameOver){
				System.out.println("You are starving to death! You must find food quickly!");
			}
		
			if (Start.player.thirst <= 0 && !Start.gameOver){
				System.out.println("You are dying of thirst! You must find water quickly!");
			}
		
			event.endUpdate();
		}
		
		if(Start.player.health <= 0){
			Start.gameOver = true;
		}
		if (!Start.gameOver){
			if (repeat){
				update();
			}
		}	
	}
	
	public void choices(){
		
		switch (choice){
		case 1:
			System.out.println("Goodbye!");
			repeat = false;
			Start.gameOver = true;
			break;
		case 2:
			pause();
			break;
		case 3:
			attack();
			break;
		case 4:
			eat();
			break;
		case 5:
			roar();
			break;
		case 6:
			search();
			break;
		case 7:
			drink();
			break;
		case 8:
			leave();
			break;
		case 9:
			stats();
			break;
		case 10:
			invalidCommand = true;
			Misc.credits();
			break;
		case 11:
			invalidCommand = true;
			System.out.println("Command removed. Changelog now found as CHANGELOG.txt in the Lion Game.zip file.");
			break;
		case 12:
			help();
			break;
		case 13:
			chase();
			break;
		case 14:
			sleep();
			break;
		case 16:
			time();
			break;
		case 17:
			rest();
			break;
		case 18:
			stalk();
			break;
		case 19:
			roam();
			break;
		case 24:
			approach();
			break;
		case 25:
			ability();
			break;
		case 404:
			invalidCommand = true;
			break;
		default:
			System.out.println("ERROR: Event class does not recognise command.");
			invalidCommand = true;
		}
		
	}

	public void pause(){
		System.out.println("You wait.");
	}
	
	public void attack(){
		System.out.println("There is nothing to attack.");
		invalidCommand = true;
	}
	
	public void eat(){
		System.out.println("There is nothing to eat.");
		invalidCommand = true;
	}
	
	public void roar(){
		
		if (Start.player.roar() == -50){
			invalidCommand = true;
		}else{
			System.out.println("You roar. Nothing happens, but it's worth it.");
		}
		
	}
	public void search(){
		System.out.println("You cannot search at this time.");
		invalidCommand = true;
	}
	public void drink(){
		System.out.println("There is nothing to drink.");
		invalidCommand = true;
	}
	
	public void chase(){
		System.out.println("You have no animals to chase at the moment.");
		invalidCommand = true;
	}
	
	public void sleep(){
		System.out.println("You cannot sleep here.");
		invalidCommand = true;
	}
	
	public void grab(){
		System.out.println("There is nothing to grab at the moment.");
		invalidCommand = true;
	}
	
	public void stalk(){
		System.out.println("There are no animals to stalk at the moment");
		invalidCommand = true;
	}
	
	public void roam(){
		System.out.println("You cannot roam here. Trying leaving this area.");
		invalidCommand = true;
	}
	
	public void leave() {
		System.out.println("You cannot leave this area.");
		invalidCommand = true;
	}
	
	public void approach(){
		System.out.println("There is nothing to approach here.");
		invalidCommand = true;
	}
	
	public void rest(){
		System.out.println("You rest for a moment.");
		System.out.println("You can sacrifice some of your food for energy. Would you like to do this?");
		boolean spendFood = userinput.getYesNoInput();
		if (spendFood){
			System.out.println("You digest some food, converting it into energy.");
			Start.player.hunger -= 10;
			Start.player.energy += 5;
		}else{
			System.out.println("You do not gain any energy.");
		}
	}
	
	public void ability(){
		int abilityChoice = userinput.getAbility();
		
		switch(abilityChoice){
		case 1:
			bite();
			break;
		case 2:
			claw();
			break;
		case 3:
			grab();
			break;
		case 4:
			pounce();
			break;
		case 404:
			invalidCommand = true;
			break;
		}
	}
	
	public void bite(){
		System.out.println("There is nothing to bite.");
		invalidCommand = true;
	}
	
	public void claw(){
		System.out.println("There is nothing to claw at.");
		invalidCommand = true;
	}
	
	public void pounce(){
		System.out.println("There is nothing to pounce at.");
		invalidCommand = true;
	}
	
	public void stats(){
		invalidCommand = true;
		Start.player.stats();
	}
	
	public void time(){
		invalidCommand = true;
		Start.environ.getTime();
	}
	
	public void help(){
		invalidCommand = true;
		System.out.println("wait - Wait a turn and do nothing");
		System.out.println("attack - Try to hit an entity you are interacting with (e.g. a zebra)");
		System.out.println("eat - Eat something you have killed");
		System.out.println("roar - Quite self explanatory. Can scare away animals");
		System.out.println("search - Search for food, drink or shelter");
		System.out.println("roam - Roam around the area. Who knows what you might come across?");
		System.out.println("drink - Drink water from watering holes");
		System.out.println("chase - Chase after an animal you are trying to hunt");
		System.out.println("approach - Simply walk towards an animal");
		System.out.println("stalk - Attempt to approach an animal without being detected");
		System.out.println("ability - Use an ability that you have unlocked");
		System.out.println("sleep - Sleep and regain some lost energy. For best results, sleep under a shelter");
		System.out.println("rest - like wait, but you can also sacrifice some food in exchange for energy");
		System.out.println("leave - Leave whatever you are doing and return to the plains");
		System.out.println("time - Display what time of day it is");
		System.out.println("stats - See your stats and skills");
		System.out.println("credits - See who helped make the game");
		System.out.println("changelog - Changes in each update");
		System.out.println("exit - Exits the game.");
		System.out.println("Unlockable abilities have their own command that you will see when you unlock them.");
	}
	
}
