/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.events;

import java.util.Random;

import game.Start;
import game.entities.GameObject;
import game.entities.animals.enemies.Enemy;
import game.world.Environment;

public class FightEvent extends Event {

	public boolean detected;
	public boolean firstAttack;
	public boolean fighting;
	int distance;
	Random r;
	
	public Enemy opponent;
	String animallc;
	
	public FightEvent(String startMessage, Enemy animal, int distance){
		this.startMessage = startMessage;
		this.distance = distance;
		opponent = animal;
		event = this;
		isInput = true;
		animallc = animal.name.toLowerCase();
		Start.objects.add(opponent);
		r = new Random();
		
		fighting = false;
		
		create();
	}
	
	public void start(){
		System.out.println(startMessage);
		repeat = true;
		if(!firstEvent){
			for(GameObject go : Start.objects)
				go.update();
		}
		
		int needed, attempt;
		
		attempt = Start.player.stealthSkill * r.nextInt(12);
		needed = ((50 - distance) / 5) + opponent.awareness;
		if (needed < attempt){
			detected = false;
		}else{
			detected = true;
		}
		
		if (Start.player.agility * r.nextInt(5) > opponent.agility * r.nextInt(5)){
			firstAttack = true;
		}else{
			firstAttack = false;
		}
		
		update();
	}
	
	public void approach(){
		if (distance > 1){
			distance -= 5;
			System.out.println("You approach five metres closer to the " + animallc + ".");
			detected = true;
		}else{
			System.out.println("You do not need to approach your opponent any more. He is right in front of you!");
		}
	}
	
	public void chase(){
		
		detected = true;
		if(Start.player.energy > 0){
			distance = distance - Start.player.speed;
			Start.player.chase();
		}else{
			System.out.println("You do not have enough energy to run towards the " + animallc + ". Try waiting or sleeping.");
		}
		
		if (distance > 1){
			distance -= Start.player.speed;
			System.out.println("You run towards the " + animallc + ".");
			detected = true;
		}else{
			System.out.println("You do not need to approach your opponent any more. He is right in front of you!");
		}
	}
	
	public void attack(){
		int a = 0;
		
		if (attackChecks()){
			a = Start.player.attack();
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void bite(){
		int a = 0;
		
		if (attackChecks()){
			int roll = r.nextInt(100);
			if (roll > 50) a = Start.player.attack() * 2;
			System.out.println("You bite at the " + animallc + "'s neck.");
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void claw(){
		int a = 0;
		
		if (attackChecks()){
			int attack1 = 0;
			int attack2 = 0;
			int roll1 = r.nextInt(100);
			if (roll1 > 30) attack1 = Start.player.attack() / 3 * 2;
			System.out.println("Attack 1 = " + attack1);
			int roll2 = r.nextInt(100);
			if (roll2 > 30) attack2 = Start.player.attack() / 3 * 2;
			System.out.println("Attack 2 = " + attack2);
			a = attack1 + attack2;
			System.out.println("You claw at the " + animallc + ".");
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void pounce(){
		int a = 0;
		
		if (attackChecks()){
			if(!detected){
				a = Start.player.attack() * 4;
				System.out.println("You pounce at the " + animallc + ", taking it by surprise!");
			}else{
				System.out.println("You must be undetected to pounce at the " + animallc + "!");
			}
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void eat(){
		if(opponent.isDead){
			System.out.println("You eat the " + animallc + ".");
			Start.player.eat(opponent.foodValue);
			repeat = false;
		}else{
			System.out.println("You cannot eat the " + animallc + " because it is still alive.");
			invalidCommand = true;
		}
	}
	
	public void roar(){
		if(!opponent.isDead){
			
			int b = Start.player.roar();
			
			if (b > opponent.courage + r.nextInt(5)){
				System.out.println("You roar at the " + animallc + ". It is scared, and runs away.");
				repeat = false;
			}else if (b == -50){
				invalidCommand = true;
			}else{
				System.out.println("Your roar fails to intimidate your opponent.");
			}
			
		}else{
			System.out.println("You roar at the dead " + animallc + ". Nothing happens, but it's worth it.");
		}
	}
	
	public void leave(){
		System.out.println("You back away from the" + animallc + ". This fight is over... for now.");
		repeat = false;
	}
	
	public void stalk(){
		
		int b; //Night-time success modifier
		if (Environment.timeID == 3){
			b = 3;
			System.out.println("You use the night-time darkness to your advantage in your attempt to sneak up on your prey. (x3 modifier)");
		}else{
			b = 1;
		}
		
		int needed, attempt;
		
		if(!opponent.isRunning){
			attempt = Start.player.stalk() * b;
			needed = Start.power(((100 - distance) / 18), 2) + opponent.awareness;
			System.out.println("Attempt: " + attempt + " Needed: " + needed);
			if (needed < attempt){
				distance = distance - 5;
				System.out.println("You successfully approach the " + animallc + " a little without being detected.");
			}else{
				System.out.println("You fail to sneak up on the " + animallc + " and it begins to flee!");
				opponent.isRunning = true;
			}
			
		}else{
			System.out.println("The " + animallc + " has detected you. You cannot sneak up on it!");
			invalidCommand = true;
		}
	}
	
	void endUpdate() {
		
		if (!opponent.isDead && distance > 1 && detected){
			if (opponent.willCharge){
				distance = distance - opponent.speed;
				System.out.println("The " + animallc + " charges towards you at top speed!");
			}else{
				distance = distance - 5;
				System.out.println("The " + animallc + " approaches 5 metres towards you.");
			}
			
		}	
		
		if (distance > 1) System.out.println("Distance: " + distance);
		
		if (distance <= 1 && !fighting){
			System.out.println("You are now close enough to your opponent to begin fighting!");
			fighting = true;
			if (!firstAttack){
				enemyTurn();
			}
		}else if (fighting){
			enemyTurn();
		}	
		
		if (distance < 0) distance = 0;
		
		if(opponent.diedThisTurn){
			System.out.println("You have managed to kill the " + animallc + ".");
			System.out.println("XP +" + opponent.xpValue);
			Start.player.xp += opponent.xpValue;
			opponent.diedThisTurn = false;
			endEvent();
		}
		
	}
	
	protected void endEvent(){
		
	}
	
	void enemyTurn(){
		
		int damage = opponent.attack + r.nextInt(5);
		System.out.println("Your opponent has dealt you " + damage + " points of damage.");
		Start.player.health -= damage;
		
	}

	public boolean attackChecks(){
		
		boolean canAttack;
		
		if (Start.player.energy > 0){
			if (distance <= 1){
				if(!opponent.isDead){
						canAttack = true;
				}else{
					System.out.println("You cannot attack the " + animallc +" because it is already dead.");
					canAttack = false;
				}
			}else{
				System.out.println("You are too far away from the " + animallc + " to attack it yet.");
				canAttack = false;
			}
		}else{
			System.out.println("You do not have enough energy to attack the " + animallc + ". Try resting or sleeping.");
			canAttack = false;
		}
		
		return canAttack;
	}
	
	public void postAttack(int a){
		if (a != 0) System.out.println("You do " + a + " damage to the " + animallc + ".");
		opponent.damage(a);
		if (a == 0) System.out.println("Your attack failed.");
	}
}
