/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.events;
import game.Start;
import game.entities.GameObject;
import game.entities.player.abilities.Ability;
import game.world.Environment;

import java.util.Random;

public class HuntEvent extends Event {

	public GameObject animal;
	public int distance;
	public boolean grabbed = false;
	public int maxRange = 150;
	Random r;
	String animallc;
	
	public HuntEvent(String startMessage, GameObject animal, int distance){
		
		this.startMessage = startMessage;
		
		this.animal = animal;
		event = this;
		isInput = true;
		this.distance = distance;
		Start.objects.add(animal);
		animallc = animal.name.toLowerCase();
		
		r = new Random();
		
		create();
	}
	
	public void approach(){
		if (distance > 1){
			distance -= 5;
			System.out.println("You approach five metres closer to the " + animallc + ".");
			animal.isRunning = true;
		}else{
			System.out.println("You do not need to approach your prey any more. It is right in front of you!");
		}
	}
	
	public void attack(){
		int a = 0;
		
		if (attackChecks()){
			a = Start.player.attack();
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void bite(){
		int a = 0;
		
		if (attackChecks()){
			int roll = r.nextInt(100);
			if (roll > 50) a = Start.player.attack() * 2;
			System.out.println("You bite at the " + animallc + "'s neck.");
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void claw(){
		int a = 0;
		
		if (attackChecks()){
			int attack1 = 0;
			int attack2 = 0;
			int roll1 = r.nextInt(100);
			if (roll1 > 30) attack1 = Start.player.attack() / 3 * 2;
			System.out.println("Attack 1 = " + attack1);
			int roll2 = r.nextInt(100);
			if (roll2 > 30) attack2 = Start.player.attack() / 3 * 2;
			System.out.println("Attack 2 = " + attack2);
			a = attack1 + attack2;
			System.out.println("You claw at the " + animallc + ".");
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void pounce(){
		int a = 0;
		
		if (attackChecks()){
			if(!animal.isRunning){
				a = Start.player.attack() * 4;
				System.out.println("You pounce at the " + animallc + ", taking it by surprise!");
			}else{
				System.out.println("You must be undetected to pounce at the " + animallc + "!");
			}
		}else{
			invalidCommand = true;
		}
		
		postAttack(a);
	}
	
	public void eat(){
		if(animal.isDead){
			System.out.println("You eat the " + animallc + ".");
			Start.player.eat(animal.foodValue);
			repeat = false;
		}else{
			System.out.println("You cannot eat the " + animallc + " because it is still alive.");
			invalidCommand = true;
		}
	}
	
	public void roar(){
		
		int b = Start.player.roar();
		
		if (b == -50){
			invalidCommand = true;
			
		}else{
			System.out.println("You roar at the " + animallc + ". It is scared, and runs away.");
			animal.isRunning = true;
		}
			
		
	}
	
	public void chase(){
		
		animal.isRunning = true;
		if(Start.player.energy > 0){
			distance = distance - Start.player.speed;
			Start.player.chase();
		}else{
			System.out.println("You do not have enough energy to continue chasing the " + animallc + ". Try waiting or sleeping.");
		}
	}
	
	public void stalk(){
		int b; //Night-time success modifier
		if (Environment.timeID == 3){
			b = 3;
			System.out.println("You use the night-time darkness to your advantage in your attempt to sneak up on your prey. (x3 modifier)");
		}else{
			b = 1;
		}
		
		int needed, attempt;
		
		if(!animal.isRunning){
			attempt = Start.player.stalk() * b;
			needed = Start.power(((100 - distance) / 18), 2) + animal.awareness;
			System.out.println("Attempt: " + attempt + " Needed: " + needed);
			if (needed < attempt){
				distance = distance - 5;
				System.out.println("You successfully approach the " + animallc + " a little without being detected.");
			}else{
				System.out.println("You fail to sneak up on the " + animallc + " and it begins to flee!");
				animal.isRunning = true;
			}
			
		}else{
			System.out.println("The " + animallc + " has detected you. You cannot sneak up on it!");
			invalidCommand = true;
		}
	}
	
	public void leave(){
		System.out.println("You leave the " + animallc + " alone.");
		repeat = false;
	}
	
	public void grab(){
		Ability ability = Ability.getAbility("Grab");
		
		if(ability.tryAbility()){
			if (distance < 2){
				if (!grabbed){
					System.out.println("You grab on to the " + animallc + ".");
					grabbed = true;
				}else{
					System.out.println("You have already grabbed the " + animallc + ".");
					invalidCommand = true;
				}
			}else{
				System.out.println("You are too far away from the " + animallc + " to grab it.");
				invalidCommand = true;
			}
		}else{
			invalidCommand = true;
		}
		
	}
	
	public void endUpdate(){
		
		if (!animal.isDead && !grabbed && animal.isRunning){
			distance = distance + animal.speed;
		}
		
		if (distance < 0) distance = 0;
		
		
		
		if (!grabbed && !animal.isDead) System.out.println("You are now " + distance + " metres away from the " + animallc + ".");
		
		if (distance > maxRange){
			System.out.println("You are too far behind the " + animallc + " and you lose sight of it. The chase is over, for now...");
			repeat = false;
		}
		
		if(animal.diedThisTurn){
			System.out.println("You have managed to kill the " + animallc + ".");
			System.out.println("XP +" + animal.xpValue);
			Start.player.xp += animal.xpValue;
			animal.diedThisTurn = false;
		}
	}
	
public boolean attackChecks(){
		
		boolean canAttack;
		
		if (Start.player.energy > 0){
			if (distance <= 1){
				if(!animal.isDead){
						canAttack = true;
				}else{
					System.out.println("You cannot attack the " + animallc +" because it is already dead.");
					canAttack = false;
				}
			}else{
				System.out.println("You are too far away from the " + animallc + " to attack it yet.");
				canAttack = false;
			}
		}else{
			System.out.println("You do not have enough energy to attack the " + animallc + ". Try resting or sleeping.");
			canAttack = false;
		}
		
		return canAttack;
	}
	
	public void postAttack(int a){
		if (a != 0) System.out.println("You do " + a + " damage to the " + animallc + ".");
		animal.damage(a);
		if (a == 0) System.out.println("Your attack failed.");
	}
	
	// lel
	
}
