/*
 *  The Lion Game - Text based adventure based on the adventures of Flinny the Lion
    Copyright (C) 2014 Adam Belcher

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

 * 
 */

package game.events;
import game.Spawn;
import game.Start;
import game.entities.GameObject;
import game.entities.animals.enemies.Enemy;
import game.world.Environment;

import java.util.Random;

public class WateringHoleEvent extends Event {

	int zebras;
	Random r;
	
	public WateringHoleEvent(String startMessage){

		this.startMessage = startMessage;
		r = new Random();
		
		event = this;
		isInput = true;
		zebras = 0;
		
		create();
	}
	
	public void drink(){
		Start.player.drink();
		System.out.println("You drink from the pool. Your thirst is now satisfied.");
	}
	
	public void search(){
		int a = userinput.getSearchInput();
		int cost = r.nextInt(30) / Start.player.search();
		
		if (a == 1){
			invalidCommand = true;
		}else if(a == 2){
			System.out.println("It takes you " + cost + " hunger and thirst to find food.");
			Start.player.hunger -= cost;
			Start.player.thirst -= cost;
			Environment.time += cost;
			
			GameObject animal = Spawn.spawnRandomPassive();
			int c = r.nextInt(30) + 10;
			newEvent = new HuntEvent("You see a " + animal.name.toLowerCase() + " " + c + " metres away.", animal, 5);
			newEvent.start();
		}else if(a == 3){
			System.out.println("You are already at a watering hole. Just go ahead and drink the water!");
			invalidCommand = true;
		}else if (a == 4){
			System.out.println("You must first leave the watering hole to find shelter.");
			invalidCommand = true;
		}else if(a == 6){
			if (Start.player.level >= 10){
				Enemy boss = Spawn.spawnBossHyena();
				newEvent = new BossEvent("You have found the alpha male of the hyenas! Let the battle begin...", boss, 20);
				newEvent.start();
			}else{
				System.out.println("Your attempts to find the hyena boss are in vain. Try again when you reach level 10.");
			}
		}
	}
	
	public void sleep(){
		System.out.println("You try to sleep, but all the wildlife around the watering hole keeps you awake.");
	}
	
	public void leave(){
		System.out.println("You leave the watering hole behind and return to the plains.");
		repeat = false;
	}
	
	void endUpdate() {
		
	}

}
